pm4py.algo.discovery.footprints.tree.variants package
=====================================================

Submodules
----------

pm4py.algo.discovery.footprints.tree.variants.bottomup module
-------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.footprints.tree.variants.bottomup
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.footprints.tree.variants
   :members:
   :undoc-members:
   :show-inheritance:
